<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Form Recipients /////////////////////////
// Buttons:
define('FORM_RECIPIENTS_HEADING', "Edit item receptores,");
define('FORM_RECIPIENTS_EDIT_FORM_RECIPIENTS_BTN', "Edit item receptores,");
// Console Text:
define('FORM_RECIPIENTS_FORM_PAGE', "forma Page");
define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Securus licet plures fuere separando per commata recipientis.");
// Popup Messages:
define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Salvis recipientis ...");
define('VIEW_FORM_TABLES_HEADING', "View formandae sunt tabulae");
define('VIEW_FORM_TABLES_BTN', "View formandae sunt tabulae");
define('VIEW_FORM_TABLES_SELECT_TABLE', "View Select a Traba");
define('VIEW_FORM_TABLES_FILTER_READ', "Filter Read Messages");
?>